#!/bin/bash
#
# alpm_stats.sh : collect and show some stats about local database.
# This file is part of Yaourt (http://archlinux.fr/yaourt-en)

loadlibrary pacman_conf
loadlibrary pkgbuild
unset repos_packages orphans repositories
pkgs_nb=0 pkgs_nb_d=0 pkgs_nb_e=0 pkgs_nb_dt=0 pkgs_nb_u=0

# set orphans, repo_packages, pkg_nb*
# parse pacman conf for ignored/hold packages
buildpackagelist()
{
	repositories=($(pkgquery -L))
	local f_foreign=1 f_explicit=2 f_deps=4 f_unrequired=8 \
		  f_upgrades=16 f_group=32 	
	while read pkgstate pkgrepo pkgname; do
		(( pkgs_nb++ ))
		(( pkgstate & f_deps )) && (( ++pkgs_nb_d )) && \
			(( pkgstate & f_unrequired )) && {
				(( pkgs_nb_dt++ ))
				orphans+=($pkgname)
			}
		(( pkgstate & f_explicit )) && (( pkgs_nb_e++ ))
		(( pkgstate & f_upgrades )) && (( pkgs_nb_u++ ))
		local reponumber=0
		for repo in ${repositories[@]}; do
			[[ "$repo" == "$pkgrepo" ]] && (( ++repos_packages[$reponumber] )) \
				&& break
			(( reponumber++ ))
		done
	done < <(pkgquery -Qf "%4 %s %n")
}

showpackagestats(){
	echo_fill "$COL_BLUE" - "$NO_COLOR"
	if [[ -t 1 ]]; then
		printf "${COL_BLUE}%${COLUMNS}s\r|${NO_COLOR}${COL_BOLD}%*s ${COL_GREEN}%s${NO_COLOR}\n" \
			"|" $((COLUMNS/2)) "Archlinux " "($NAME $VERSION)"
	else
		printf "%*s %s\n" 40 "Archlinux " "($NAME $VERSION)"
	fi
	echo_fill "$COL_BLUE" - "$NO_COLOR"
	echo; echo_fill "$COL_BLUE" - "$NO_COLOR"
	echo -e "${COL_GREEN}$(gettext 'Total installed packages:')  ${COL_YELLOW}$pkgs_nb"	
	echo -e "${COL_GREEN}$(gettext 'Explicitly installed packages:')  ${NO_COLOR}${COL_YELLOW}$pkgs_nb_e"	
	echo -e "${COL_GREEN}$(gettext 'Packages installed as dependencies to run other packages:')  ${COL_YELLOW}$pkgs_nb_d"   
	echo -e "${COL_GREEN}$(gettext 'Packages out of date:')  ${COL_YELLOW}$pkgs_nb_u"   
	if (( pkgs_nb_dt )); then
		echo -e "${COL_RED}$(eval_gettext 'Where $pkgs_nb_dt packages seems no more used by any package:')${NO_COLOR}"
		echo_wrap 4 "${orphans[*]}"
	fi
	echo -e "${COL_GREEN}$(gettext 'Hold packages:') (${#HoldPkg[@]}) ${NO_COLOR}${COL_YELLOW}${HoldPkg[@]}"
	echo -e "${COL_GREEN}$(gettext 'Ignored packages:') (${#IgnorePkg[@]}) ${NO_COLOR}${COL_YELLOW}${IgnorePkg[@]}"
	echo -e "${COL_GREEN}$(gettext 'Ignored groups:') (${#IgnoreGroup[@]}) ${NO_COLOR}${COL_YELLOW}${IgnoreGroup[@]}"
	echo; echo_fill "$COL_BLUE" - "$NO_COLOR"
}

showrepostats(){
	local strout=""
	echo -e "${COL_GREEN}$(gettext 'Number of configured repositories:')  ${NO_COLOR}${COL_YELLOW}${#repositories[@]}"
	echo -e "${COL_GREEN}$(gettext 'Packages by repositories (ordered by pacman''s priority)')${NO_COLOR}:"
	local reponumber=0 pkgs_l=0
	for repo in ${repositories[@]}; do
		[[ ${repos_packages[$reponumber]} ]] || repos_packages[$reponumber]=0
		(( pkgs_l+=repos_packages[$reponumber] ))
		strout+="${repo}(${repos_packages[$reponumber]}), "
		(( reponumber++ ))
	done
	strout+=" $(gettext 'others')*($((pkgs_nb-pkgs_l)))"
	str_wrap 4 "$strout"
	strwrap=${strwrap//\(/$COL_YELLOW\(}
	strwrap=${strwrap//)/)$NO_COLOR}
	echo -e "$strwrap"
	echo
	echo_wrap 4 "*$(gettext 'others') $(gettext 'are packages from local build or AUR Unsupported')"
	echo; echo_fill "$COL_BLUE" - "$NO_COLOR"
}

showdiskusage()
{
	local cachedir size_t=0 size_r=0 i=1 _msg_label _msg_prog

	# Get space used by installed package (from info in alpm db)
	_msg_label=$(gettext 'Theorical - Real space used by packages:')
	_msg_prog=$(gettext 'progression:')
	while read s_t s_r; do
		(( size_t+=s_t ))
		(( size_r+=s_r ))
		[[ -t 1 ]] && \
			echo -ne "\r${COL_GREEN} $_msg_label ${COL_YELLOW}$(($size_t/1048576))M -  $(($size_r/1048576))M $_msg_prog $((i++))/$pkgs_nb"
	done < <(pkgquery -Qf "%2 %3")
	[[ -t 1 ]] && { echo -en "\r"  ; echo_fill "" " " ""; }
	echo -e "${COL_GREEN}$(gettext 'Theorical space used by packages:') ${COL_YELLOW}$(($size_t/1048576))M"
	echo -e "${COL_GREEN}$(gettext 'Real space used by packages:') ${COL_YELLOW}$(($size_r/1048576))M"	
	# Get cachedir
	cachedir=(`pacman_parse --debug 2>/dev/null | grep "^debug: option 'cachedir'" |awk '{print $5}'`)
	# space used by download packages or sources in cache
	echo -e "${COL_GREEN}$(gettext 'Space used by pkg downloaded in cache (cachedir):') ${COL_YELLOW} $(du -sh $cachedir 2>/dev/null|awk '{print $1}')"
	[[ "$SRCDEST" ]] && srcdestsize=`du -sh $SRCDEST 2>/dev/null|awk '{print $1}'` || srcdestsize=null
	echo -e "${COL_GREEN}$(gettext 'Space used by src downloaded in cache:') ${COL_YELLOW} $srcdestsize$NO_COLOR"
}
# vim: set ts=4 sw=4 noet: 
